==> localnews-activity-api-2.0.8-sources.jar: com/bxm/localnews/activity/controller/MissionController.java <==
package com.bxm.localnews.activity.controller;

import javax.annotation.Resource;

import com.bxm.localnews.activity.dto.AppletAppTaskResultDTO;
import com.bxm.localnews.activity.service.MissionService;
import com.bxm.localnews.activity.vo.BaskInfoMeta;
import com.bxm.localnews.activity.vo.MissionModel;
import com.bxm.localnews.common.annotation.TouTiaoAuth;
import com.bxm.localnews.common.util.ResultUtil;
import com.bxm.localnews.common.vo.Json;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

@Api(tags = "2-02 个人任务相关接口", description = "包括新手任务和日常任务")
@RestController
@RequestMapping("api/mission")
public class MissionController {

    @Resource
    private MissionService missionService;

    @ApiOperation(value = "2-02-1 获取任务中心列表,包括个人任务和新手任务", notes = "")

    @ApiImplicitParams({
            @ApiImplicitParam(name = "userId", value = "用户ID", required = true),
            @ApiImplicitParam(name = "areaCode", value = "地区编码", required = false),
    })
    @RequestMapping(value = "listMission", method = RequestMethod.POST)
    public Json<MissionModel> listMission(@RequestParam(value = "userId") Long userId, @RequestParam(value = "areaCode", required = false) String areaCode,
                                          @RequestParam(required = false) String curVer, @RequestParam(value = "platform") Integer platform) {
        return this.missionService.listMissions(userId, areaCode, curVer, platform);
    }

    @ApiOperation(value = "2-02-3 晒收入,获取用户基本信息", notes = "")
    @ApiImplicitParam(name = "userId", value = "用户ID", required = true)
    @RequestMapping(value = "baskInfo", method = RequestMethod.POST)
    @TouTiaoAuth
    public Json<BaskInfoMeta> baskInfo(@RequestParam(value = "userId") Long userId) {
        return this.missionService.baskInfo(userId);
    }

    @ApiOperation(value = "2-02-4 完成特定场景任务", notes = "小程序完成任务调用：收藏(1104),关注微信公众号-0001,转发本地新闻-0002")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "userId", value = "用户id", required = true),
            @ApiImplicitParam(name = "scene", value = "场景值", required = true)
    })
    @RequestMapping(value = "/sceneTask", method = RequestMethod.POST)
    public Json<AppletAppTaskResultDTO> completeSceneTask(@RequestParam("userId") Long userId, @RequestParam("scene") String scene) {
        return ResultUtil.genSuccessResult(missionService.completeSceneTask(userId, scene));
    }

}

==> localnews-activity-api-3.11.0-sources.jar: com/bxm/localnews/activity/controller/MissionController.java <==
package com.bxm.localnews.activity.controller;

import com.bxm.localnews.activity.dto.AppletAppTaskResultDTO;
import com.bxm.localnews.activity.dto.NewsMissionRewardDto;
import com.bxm.localnews.activity.service.MissionService;
import com.bxm.localnews.activity.vo.BaskInfoMeta;
import com.bxm.localnews.activity.vo.MissionModel;
import com.bxm.localnews.common.annotation.TouTiaoAuth;
import com.bxm.localnews.common.constant.TaskEnum;
import com.bxm.localnews.common.util.ResultUtil;
import com.bxm.localnews.common.vo.Json;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;

@Api(tags = "2-02 个人任务相关接口", description = "包括新手任务和日常任务")
@RestController
@RequestMapping("api/mission")
@Slf4j
public class MissionController {

    @Resource
    private MissionService missionService;

    @ApiOperation(value = "2-02-1 获取任务中心列表,包括个人任务和新手任务", notes = "")

    @ApiImplicitParams({
            @ApiImplicitParam(name = "userId", value = "用户ID", required = true),
            @ApiImplicitParam(name = "areaCode", value = "地区编码", required = false),
    })
    @RequestMapping(value = "listMission", method = RequestMethod.POST)
    public Json<MissionModel> listMission(@RequestParam(value = "userId") Long userId, @RequestParam(value = "areaCode", required = false) String areaCode,
                                          @RequestParam(required = false) String curVer, @RequestParam(value = "platform") Integer platform) {
        return missionService.listMissions(userId, areaCode, curVer, platform);
    }

    @ApiOperation(value = "2-02-3 晒收入,获取用户基本信息", notes = "")
    @ApiImplicitParam(name = "userId", value = "用户ID", required = true)
    @RequestMapping(value = "baskInfo", method = RequestMethod.POST)
    @TouTiaoAuth
    public Json<BaskInfoMeta> baskInfo(@RequestParam(value = "userId") Long userId) {
        return missionService.baskInfo(userId);
    }

    @ApiOperation(value = "2-02-4 完成特定场景任务", notes = "小程序完成任务调用：收藏(1104),关注微信公众号-0001,转发本地新闻-0002")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "userId", value = "用户id", required = true),
            @ApiImplicitParam(name = "scene", value = "场景值", required = true)
    })
    @RequestMapping(value = "/sceneTask", method = RequestMethod.POST)
    public Json<AppletAppTaskResultDTO> completeSceneTask(@RequestParam("userId") Long userId, @RequestParam("scene") String scene) {
        return ResultUtil.genSuccessResult(missionService.completeSceneTask(userId, scene));
    }

    @ApiOperation("2-02-5 完成指定的任务")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "userId", value = "完成任务的用户ID"),
            @ApiImplicitParam(name = "taskName", value = "任务编码，看视频赚小红花：TASK_WATCH_VIDEO"),
            @ApiImplicitParam(name = "relationId", value = "完成任务关联的ID")
    })
    @PostMapping("comple")
    public Json<NewsMissionRewardDto> compleTask(@RequestParam Long userId,
                                                 @RequestParam String taskName,
                                                 @RequestParam(required = false) String relationId,
                                                 @RequestParam(required = false) String content) {
        TaskEnum task = null;

        try {
            task = TaskEnum.valueOf(taskName);
        } catch (Exception e) {
            log.error("任务类型[{}]不存在", taskName);
        }

        if (null == task) {
            return ResultUtil.genFailedResult("任务不存在");
        }

        NewsMissionRewardDto reward = missionService.completeTask(userId, TaskEnum.valueOf(taskName), relationId, content);

        return ResultUtil.genSuccessResult(reward);
    }

}
